@@ -1,5 +1,5 @@
 normSpectra <-
-function(spectra, method = "ti") {
+function(spectra, method = "TotInt", RangeExpress = NULL) {
 	
 # Function to Normalize the data in a Spectra object
 # Part of the ChemoSpec package
@@ -10,13 +10,24 @@ function(spectra, method = "ti") {
 
 # normalize by a row by the sum of its entries:
 
-	if (method == "ti") {
+	if (method == "TotInt") {
 		for (n in 1:length(spectra$names)) {
 			S <- sum(spectra$data[n,])
 			spectra$data[n,] <- spectra$data[n,]/S
 			}
 		}
 
+# normalize by a range of specified values:
+
+	if (method == "Range") {
+		if (is.null(RangeExpress)) stop("No range expression given")
+		rfi <- which(RangeExpress)
+		for (n in 1:length(spectra$names)) {
+			S <- sum(spectra$data[n,rfi])
+			spectra$data[n,] <- spectra$data[n,]/S
+			}
+		}
+
 	chkSpectra(spectra)
 	spectra
 	}
